//                                               -*- C++ -*-
/**
 * @file  TTY.cxx
 * @brief This file provides definitions for tty control sequences
 *
 * (C) Copyright 2005-2011 EDF
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 *
 * @author $LastChangedBy: dutka $
 * @date   $LastChangedDate: 2011-04-08 17:04:10 +0200 (Fri, 08 Apr 2011) $
 */

#include "TTY.hxx"

namespace OpenTURNS {

#ifndef WIN32
  static volatile Bool Colored( true  ); // default is colored output
#else
  static volatile Bool Colored( false ); // default is standard output
#endif

  static const char * ColorMap[] = {
    /* ISO 6429 color sequences */
    "\033[0m", /* DEFAULT */
    "\033[1m", /* BOLD */
    "\033[4m", /* UNDERLINE */
    "\033[5m", /* BLINK */
      
    /* Foreground */
    "\033[30m", /* BLACKFG */
    "\033[31m", /* REDFG */
    "\033[32m", /* GREENFG */
    "\033[33m", /* YELLOWFG */
    "\033[34m", /* BLUEFG */
    "\033[35m", /* PURPLEFG */
    "\033[36m", /* CYANFG */
    "\033[37m", /* WHITEFG */
      
    /* Background */
    "\033[30m", /* BLACKBG */
    "\033[31m", /* REDBG */
    "\033[32m", /* GREENBG */
    "\033[33m", /* YELLOWBG */
    "\033[34m", /* BLUEBG */
    "\033[35m", /* PURPLEBG */
    "\033[36m", /* CYANBG */
    "\033[37m", /* WHITEBG */
  };

  /* Return a control sequence corresponding to the current color */
  const char * TTY::GetColor( Color c )
  {
    if ( !Colored || (c < 0) || (c >= LASTCOLOR) ) return "";
    return ColorMap[ c ];
  }

  /* Define the colorization strategy. Flag = true if colored output */
  /* Q: Do we need to perform MT-safe programming ? Not sure. Ivan   */
  void TTY::ShowColors( Bool flag )
  {
    Colored = flag;
  }

  /* Query the colorization strategy. Return true if colored output */
  Bool TTY::ColoredOutput()
  {
    return Colored;
  }
} // namespace OpenTURNS
