//                                               -*- C++ -*-
/**
 *  @file  Cloud.hxx
 *  @brief Cloud class for cloud plots
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2011-04-11 12:32:27 +0200 (Mon, 11 Apr 2011) $
 *  Id:      $Id: Cloud.hxx 1866 2011-04-11 10:32:27Z schueller $
 */
#ifndef OPENTURNS_CLOUD_HXX
#define OPENTURNS_CLOUD_HXX

#include "OTprivate.hxx"
#include "DrawableImplementation.hxx"
#include "NumericalSample.hxx"
#include "Collection.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Graph {

      /**
       * @class Cloud
       *
       * The class describing a cloud plot
       * Instance of Drawable
       */

      class Cloud : public DrawableImplementation
      {
        CLASSNAME;
      public:

        typedef DrawableImplementation::NumericalSample          NumericalSample;
        typedef DrawableImplementation::InvalidArgumentException InvalidArgumentException;
        typedef DrawableImplementation::StorageManager           StorageManager;
        typedef Type::Collection<NumericalComplex>               NumericalComplexCollection;

        /** Default constructor */
        Cloud(const NumericalSample & data,
              const String & legend = NoSpecifiedLabel)
          /* throw(InvalidArgumentException) */;

        /** Constructor from complex numbers */
        Cloud(const NumericalComplexCollection & data,
              const String & legend = NoSpecifiedLabel)
          /* throw(InvalidArgumentException) */;

        /** Contructor from 2 data sets */
        Cloud(const NumericalSample & dataX,
              const NumericalSample & dataY,
              const String & legend = NoSpecifiedLabel);

        /** Constructor with parameters */
        Cloud(const NumericalSample & data,
              const String & color,
              const String & pointStyle,
              const String & legend = NoSpecifiedLabel)
          /* throw(InvalidArgumentException) */;

        /** String converter */
        String __repr__() const;

        /** Draw method */
        String draw() const;

        /** Clone method */
        Cloud * clone() const;

        /** Check fo data validity */
        Bool isValidData(const NumericalSample & data) const;

        /** Method save() stores the object through the StorageManager */
        void save(StorageManager::Advocate & adv) const;

        /** Method load() stores the object through the StorageManager */
        void load(StorageManager::Advocate & adv);

      private:

        Cloud() {};
        friend class Base::Common::Factory<Cloud>;

      }; /* class Cloud */

    }/* namespace Graph */
  }/*namespace Base */
}/* namespace OpenTURNS */
#endif /* OPENTURNS_CLOUD_HXX */
