//                                               -*- C++ -*-
/**
 *  @file  ExperimentImplementation.cxx
 *  @brief Abstract top-level view of an experiment plane
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: ExperimentImplementation.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include "OTprivate.hxx"
#include "ExperimentImplementation.hxx"
#include "Exception.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      typedef Base::Common::NotYetImplementedException NotYetImplementedException;

      CLASSNAMEINIT(ExperimentImplementation);

      /* Default constructor */
      ExperimentImplementation::ExperimentImplementation(const String & name):
        PersistentObject(name)
      {
        // Nothing to do
      }

      /* Virtual constructor */
      ExperimentImplementation * ExperimentImplementation::clone() const
      {
        return new ExperimentImplementation(*this);
      }

      /* String converter */
      String ExperimentImplementation::__repr__() const
      {
        OSS oss;
        oss << "class=" << GetClassName()
            << " name=" << getName();
        return oss;
      }

      /* Sample generation */
      ExperimentImplementation::NumericalSample ExperimentImplementation::generate()
      {
        throw NotYetImplementedException(HERE);
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
