//                                               -*- C++ -*-
/**
 *  @file  EnumerateFunctionImplementation.cxx
 *  @brief The bijective function to select polynomials in the orthogonal basis
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 11:21:38 +0200 (Wed, 21 May 2008) $
 *  Id:      $Id: Object.cxx 815 2008-05-21 09:21:38Z dutka $
 */
#include "EnumerateFunctionImplementation.hxx"
#include "OSS.hxx"
#include "PersistentObjectFactory.hxx"
#include "Exception.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(EnumerateFunctionImplementation);

      typedef Base::Common::NotYetImplementedException                              NotYetImplementedException;
      typedef Base::Common::InvalidArgumentException                                InvalidArgumentException;
      typedef Base::Type::Indices                                                   Indices;

      /* Parameter constructor */
      EnumerateFunctionImplementation::EnumerateFunctionImplementation(const UnsignedLong dimension)
        : Base::Common::PersistentObject(),
          dimension_(dimension)
      {
        if ( dimension == 0 )
          throw InvalidArgumentException ( HERE ) << "Cannot build an EnumerateFunction of dimension 0.";
      }

      /* String converter */
      String EnumerateFunctionImplementation::__repr__() const
      {
        return OSS() << "class=" << getClassName()
                     << " dimension=" << dimension_;
      }

      /* The inverse of the association */
      UnsignedLong EnumerateFunctionImplementation::inverse(const Indices & indices) const
      {
        throw NotYetImplementedException( HERE );
      }

      /* Dimension accessor */
      void EnumerateFunctionImplementation::setDimension(const UnsignedLong dimension)
      {
        dimension_ = dimension;
      }

      UnsignedLong EnumerateFunctionImplementation::getDimension() const
      {
        return dimension_;
      }

      /* Method save() stores the object through the StorageManager */
      void EnumerateFunctionImplementation::save(StorageManager::Advocate & adv) const
      {
        PersistentObject::save( adv );
        adv.saveAttribute( "dimension_", dimension_ );
      }

      /* Method load() reloads the object from the StorageManager */
      void EnumerateFunctionImplementation::load(StorageManager::Advocate & adv)
      {
        PersistentObject::load( adv );
        adv.loadAttribute( "dimension_", dimension_ );
      }


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
