//                                               -*- C++ -*-
/**
 *  @file  PostAnalyticalControlledImportanceSampling.hxx
 *  @brief PostAnalyticalControlledImportanceSampling is an implementation of the importance sampling Montex Carlo simulation method
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2011-04-11 12:32:27 +0200 (Mon, 11 Apr 2011) $
 *  Id:      $Id: PostAnalyticalControlledImportanceSampling.hxx 1866 2011-04-11 10:32:27Z schueller $
 */
#ifndef OPENTURNS_POSTANALYTICALCONTROLLEDIMPORTANCESAMPLING_HXX
#define OPENTURNS_POSTANALYTICALCONTROLLEDIMPORTANCESAMPLING_HXX

#include "PostAnalyticalSimulation.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      /**
       * @class PostAnalyticalControlledImportanceSampling
       */

      class PostAnalyticalControlledImportanceSampling :
        public PostAnalyticalSimulation
      {

        CLASSNAME;
      public:

        typedef PostAnalyticalSimulation::NumericalSample          NumericalSample;
        typedef PostAnalyticalSimulation::InvalidArgumentException InvalidArgumentException;
        typedef PostAnalyticalSimulation::StandardEvent            StandardEvent;
        typedef PostAnalyticalSimulation::Distribution             Distribution;

        /** Constructor with parameters */
        PostAnalyticalControlledImportanceSampling(const AnalyticalResult & AnalyticalResult);

        /** Virtual constructor */
        virtual PostAnalyticalControlledImportanceSampling * clone() const;

        /** String converter */
        String __repr__() const;

      private:

        /** Compute the block sample */
        NumericalSample computeBlockSample(NumericalSample & realizedEventSample);

      } ; /* class PostAnalyticalControlledImportanceSampling */

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_POSTANALYTICALCONTROLLEDIMPORTANCESAMPLING_HXX */
