//                                               -*- C++ -*-
/**
 *  @file  BinomialFactory.hxx
 *  @brief Factory for Binomial distribution
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: BinomialFactory.hxx 1473 2010-02-04 15:44:49Z dutka $
 */
#ifndef OPENTURNS_BINOMIALFACTORY_HXX
#define OPENTURNS_BINOMIALFACTORY_HXX

#include "OTprivate.hxx"
#include "DistributionImplementationFactory.hxx"
#include "Binomial.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Distribution {

      /**
       * @class BinomialFactory
       */
      class BinomialFactory
        : public Model::DistributionImplementationFactory
      {
      public:

        typedef Model::DistributionImplementationFactory                    DistributionImplementationFactory; // required by SWIG
        typedef DistributionImplementationFactory::NumericalSample          NumericalSample;
        typedef DistributionImplementationFactory::InternalException        InternalException;
        typedef DistributionImplementationFactory::InvalidArgumentException InvalidArgumentException;

        /** Default constructor */
        BinomialFactory();

        /** Virtual constructor */
        virtual BinomialFactory * clone() const;

        /* Here is the interface that all derived class must implement */
        using DistributionImplementationFactory::build;

        Binomial * build(const NumericalSample & sample) const /* throw(InvalidArgumentException, InternalException) */;
        Binomial * build(const NumericalPointCollection & parameters) const /* throw(InvalidArgumentException, InternalException) */;
        Binomial * build() const /* throw(InvalidArgumentException, InternalException) */;

        //      private:
        // Compute the log-likelihood of a sample
        static NumericalScalar ComputeLogLikelihood(const UnsignedLong n,
                                                    const NumericalScalar p,
                                                    const NumericalSample & sample);

      }; /* class BinomialFactory */


    } /* namespace Distribution */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_BINOMIALFACTORY_HXX */
