//                                               -*- C++ -*-
/**
 *  @file  LogNormalFactory.hxx
 *  @brief Factory for LogNormal distribution
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2011-05-24 19:30:41 +0200 (Tue, 24 May 2011) $
 *  Id:      $Id: LogNormalFactory.hxx 1910 2011-05-24 17:30:41Z schueller $
 */
#ifndef OPENTURNS_LOGNORMALFACTORY_HXX
#define OPENTURNS_LOGNORMALFACTORY_HXX

#include "OTprivate.hxx"
#include "DistributionImplementationFactory.hxx"
#include "LogNormal.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Distribution {

      /**
       * @class LogNormalFactory
       */
      class LogNormalFactory
        : public Model::DistributionImplementationFactory
      {
      public:

        typedef Model::DistributionImplementationFactory                    DistributionImplementationFactory; // required by SWIG
        typedef DistributionImplementationFactory::NumericalSample          NumericalSample;
        typedef NumericalSample::NumericalPoint                             NumericalPoint;
        typedef DistributionImplementationFactory::InternalException        InternalException;
        typedef DistributionImplementationFactory::InvalidArgumentException InvalidArgumentException;

        /** Default constructor */
        LogNormalFactory();

        /** Virtual constructor */
        virtual LogNormalFactory * clone() const;

        /* Here is the interface that all derived class must implement */
        using DistributionImplementationFactory::build;

        LogNormal * build(const NumericalSample & sample) const /* throw(InvalidArgumentException, InternalException) */;
        LogNormal * build(const NumericalPointCollection & parameters) const /* throw(InvalidArgumentException, InternalException) */;
        LogNormal * build() const /* throw(InvalidArgumentException, InternalException) */;

      private:
        /* Compute the different sums needed by the likelihood maximization */
        static NumericalPoint ComputeMaximumLikelihoodSums(const NumericalScalar gamma,
                                                           const NumericalSample & sample);

        /* Compute the maximum likelihood constraint for the shift parameter \gamma */
        static NumericalScalar ComputeConstraint(const NumericalPoint & sums);

      }; /* class LogNormalFactory */


    } /* namespace Distribution */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_LOGNORMALFACTORY_HXX */
